/*
 * Copyright (C) 2008 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.gxp.compiler.validate;

import com.google.gxp.compiler.alerts.ErrorAlert;
import com.google.gxp.compiler.alerts.SourcePosition;
import com.google.gxp.compiler.base.AbbrExpression;

/**
 * An {@link com.google.gxp.compiler.alerts.Alert Alert} that indicates that
 * a conflicting variable name was found.  This can come from either nested
 * <gxp:abbr>s with the same name, or a <gxp:abbr> with the same name as a
 * <gxp:param>.
 */
public class ConflictingVarNameError extends ErrorAlert {
  public ConflictingVarNameError(SourcePosition pos, String displayName, String name) {
    super(pos, displayName + " has the same name as an outer variable: " + name);
  }

  public ConflictingVarNameError(AbbrExpression abbr) {
    this(abbr.getSourcePosition(), abbr.getDisplayName(), abbr.getName());
  }
}
